# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0-alpha5] - 2024-10-21

### Added

- M3U media sources can now be added to the playout.
- New profile and user management pages have been added.
- An experimental dark mode has been added.
- Images can now be flipped, mirrored and cropped in the image editor.
- Images must now match the required aspect ratios defined in the radio settings.
- Shows can now be filtered by category.
- The calendar day and week view now show detailed information on fallback slots.

### Fixed

- Filenames are no longer used as alternative text for images.
- Image license and license related fields are now properly saved.
- Image license requirements are now properly validated.
- Show danger zone is now hidden if it doesn’t contain any actionable items due to permissions.
- Error handling for media sources has been improved.
- The HTML editor now behaves more like a normal input field.
- Assets are now cached for better performance.
- The image picker no longer retains any unsaved changes after the dialog has been closed.
- View state like search, filter and ordering parameters are now reflected in the URL so users can share URLS.
- The currently selected show is cleared after logout.
- Fixed minor UI- and UI-related accessibility issues, as well as typos.

### Changed

- Line-in inputs are now based on the radio settings instead of being hardcoded.
- Deselection of images is now part of the dialog instead of the image preview.
- The visual appearance of the calendar day view has been completely overhauled.
- Data being fetched from the server is now being aggregated to improve performance and reduce the number of flashes of content.
- Users can now end a schedule after a specific timeslot, replacing the previous option of manually deleting timeslots in the backend.


## [1.0.0-alpha4] - 2024-04-16

### Added

- Implemented basic permissions so that unprivileged users either can’t see or can’t edit data they are not allowed to see or edit.
- Episodes that the dashboard detects as invalid (e.g. those with a negative duration) are now highlighted with a yellow background and red stripes and should be reported.
- The menu now has a link to the steering administration page.

### Fixed

- Fixed some visual spacing issues with dialogs.
- The title column in the episode list will now always display a title or placeholder.
- Users can now always abort the conflict resolution mode in the calendar.
- Fixed some rendering issues for certain conflict resolutions in the calendar.
- Fixed some missing, misleading and invalid translations in the calendar.

### Changed

- Calendar event color scheme has been re-worked to be more readable and distinguishes between owned and other shows.
- Reworked calendar dialogs and grouped related information and actions.
- Drastically reduced asset sizes and therefore improved app load times.
- The *Delete all following episodes*-functionality has been temporarily disabled.
- The show quick selector has been removed because we provide similar functionality on the show overview page.
- Changed the aura user and group ID from 2872 to 872.

## [1.0.0-alpha3] - 2023-02-26

### Added

- Added license selection in image picker.
- Added show overview page with grid and table view including pagination, search and extensive ordering capabilities.
- The state of save operations is now communicated to users.
- The media page has been removed in favor of inline editors in the episode and show management pages.
- Hierarchical pages now display a breadcrumb navigation. 
- Show pages now display update/create metadata.
- All pages and subviews now have unique and shareable URLs.
- A new login page has been added.
- Shows can now be deleted.
- The show slug can now be changed.
- Languages and topics can now be set for individual episodes/notes.
- Show on-air and next-up info for episodes.
- Added support for viewing past episodes.
- Added support for viewing inactive schedules.
- Platform and social media links can now be added to shows and episodes.
- Content fields now have a WYSIWYG-HTML editor.

### Fixed

- Fixed overflow issues for in image picker.
- Ensure save errors due to connection issues are properly communicated to the user.
- Fixed keyboard selection support in image picker.
- Fixed overflow issues in calendar.
- Fixed overflow issues in show quick selector for long show titles.

### Changed

- The global navigation has been moved to a sidebar.
- The global navigation now includes contextualized submenus.
- The show admin selector now uses an inline selection mechanism instead of a dialog.
- The help link in the footer now directly links to the AURA documentation.
- The page-size selection for the episode table has been moved to the table footer.
- The range-end selection in the episode table has been removed.
- The range-start selection in the episode table is now positioned right next to the table header.
- The episode/note editor is now a separate page instead of a modal.
- The show deactivation button has been moved to the *Danger zone* and now requires confirmation.
- The show page has been split into two separate pages for episodes/schedules and basic settings.
- Related individual fields in the basic show settings have been restructured into structured blocks.
- Updated/harmonized terms used in show pages.
- The unimplemented settings page has been removed.

## [1.0.0-alpha2] - 2023-06-20

### Added

- a new show selector to the navbar (#122, f9762d85).
- a new image picker that can be used to upload new and select existing images (#89, #139, e0fd0a76, b335d801, 57e1e10f).
- ability to add internal notes to a show (#146, 319cf540).
- information on empty slots between shows and a progress indicator for the currently playing show
  to the calendar day-view (#155, 9ac48a55, 2a68a7ac).
- a progress indicator for the currently playing show to the calendar week-view (#156, b52672dd).
- ability to add and remove individual contributors to the show notes based on the show owners (#170, #146, aa707763).
- ability to add tags to show notes (#146, 560d8dda).

### Fixed

- Navigation would sometimes freeze, after an application error in the playlists view (#132, e4083e66).
- Calendar would sometimes crash if playlist data is missing (#132, a3e8e3b0).
- Switching between the week- and day-view in the calendar no longer squishes the week-view (#153, e28eb4f7).
- The calendar uses entire viewport height now (#154, 4c90f277).
- Users are now able to create a timeslot in a calendar week slot that has already started (#167, 3d4e9b28).
- HTML in the show title, short description and description is now correctly rendered (#129, 649b4c0b).

### Changed

- The timeslot overview has been fully revised (4ef88279).
- The timeslot show notes editor has been fully revised (#141, 57e1e10f).
- Past schedules are now hidden in the show manager (#120, 8cd743de).
- Schedules are now shown with their respective start and end date (#121, f9dc6fef).
- The calendar day-view has been fully revised (#155, 9ac48a55, 2a68a7ac).
- The slots in the calendar week-view have been from 30 to 15 minutes to make it easier to
  create shorter slots (#151, 3fc47383).
- Very short timeslots in the calendar week-view now take up less space (#151, 3fc47383, bfe7f813).
- Show start and end time in calendar tooltip if the event is too short to render it as content (#173, cf5ac12e).
- The show manager interface for editing the show details has been overhauled, changing the overall appearance
  and the way some of the fields are edited (db7dc49d).

### Removed

- Non-functional nav button to broadcast management on show detail page (#133, e4083e66).

## [1.0.0-alpha1] - 2023-02-27

Initial release.
